@@ -1,11 +1,9 @@
 import os
 import base64
-import sys
-
-from six.moves import configparser
+import configparser
 
 from keyring import errors
-from keyring.util.escape import escape as escape_for_ini
+from .escape import escape as escape_for_ini
 from keyring.util import platform_, properties
 from keyring.backend import KeyringBackend, NullCrypter
 from . import keyczar
@@ -22,12 +20,12 @@ except ImportError:
 
 def has_pyfs():
     """
-    Does this environment have pyfs installed?
+    Does this environment have pyfs 1.x installed?
     Should return False even when Mercurial's Demand Import allowed import of
     fs.*.
     """
     with errors.ExceptionRaisedContext() as exc:
-        fs.__name__
+        fs.opener.opener
     return not bool(exc)
 
 
@@ -45,8 +43,7 @@ class BasicKeyring(KeyringBackend):
 
     _filename = 'keyring_pyf_pass.cfg'
 
-    def __init__(self, crypter, filename=None, can_create=True,
-                 cache_timeout=None):
+    def __init__(self, crypter, filename=None, can_create=True, cache_timeout=None):
         super(BasicKeyring, self).__init__()
         self._crypter = crypter
         def_fn = os.path.join(platform_.data_root(), self.__class__._filename)
@@ -64,46 +61,42 @@ class BasicKeyring(KeyringBackend):
 
     @property
     def filename(self):
-        """The filename used to store the passwords.
-        """
+        """The filename used to store the passwords."""
         return self._filename
 
     def encrypt(self, password):
-        """Encrypt the password.
-        """
+        """Encrypt the password."""
         if not password or not self._crypter:
             return password or b''
         return self._crypter.encrypt(password)
 
     def decrypt(self, password_encrypted):
-        """Decrypt the password.
-        """
+        """Decrypt the password."""
         if not password_encrypted or not self._crypter:
             return password_encrypted or b''
         return self._crypter.decrypt(password_encrypted)
 
     def _open(self, mode='r'):
-        """Open the password file in the specified mode
-        """
+        """Open the password file in the specified mode"""
         open_file = None
         writeable = 'w' in mode or 'a' in mode or '+' in mode
         try:
             # NOTE: currently the MemOpener does not split off any filename
             #       which causes errors on close()
             #       so we add a dummy name and open it separately
-            if (self.filename.startswith('mem://') or
-                    self.filename.startswith('ram://')):
-                open_file = fs.opener.fsopendir(self.filename).open('kr.cfg',
-                                                                    mode)
+            if self.filename.startswith('mem://') or self.filename.startswith('ram://'):
+                open_file = fs.opener.fsopendir(self.filename).open('kr.cfg', mode)
             else:
                 if not hasattr(self, '_pyfs'):
                     # reuse the pyfilesystem and path
                     self._pyfs, self._path = fs.opener.opener.parse(
-                        self.filename, writeable=writeable)
+                        self.filename, writeable=writeable
+                    )
                     # cache if permitted
                     if self._cache_timeout is not None:
                         self._pyfs = fs.remote.CacheFS(
-                            self._pyfs, cache_timeout=self._cache_timeout)
+                            self._pyfs, cache_timeout=self._cache_timeout
+                        )
                 open_file = self._pyfs.open(self._path, mode)
         except fs.errors.ResourceNotFoundError:
             if self._can_create:
@@ -121,12 +114,12 @@ class BasicKeyring(KeyringBackend):
                         else:
                             url2 = ''
                         host = split_url2[0]
-                    pyfs = fs.opener.opener.opendir(
-                        '%s://%s' % (fs_name, host))
+                    pyfs = fs.opener.opener.opendir('%s://%s' % (fs_name, host))
                     # cache if permitted
                     if self._cache_timeout is not None:
                         pyfs = fs.remote.CacheFS(
-                            pyfs, cache_timeout=self._cache_timeout)
+                            pyfs, cache_timeout=self._cache_timeout
+                        )
                     # NOTE: fs.path.split does not function in the same
                     # way os os.path.split... at least under windows
                     url2_path, url2_filename = os.path.split(url2)
@@ -159,8 +152,7 @@ class BasicKeyring(KeyringBackend):
 
     @property
     def config(self):
-        """load the passwords from the config file
-        """
+        """load the passwords from the config file"""
         if not hasattr(self, '_config'):
             raw_config = configparser.RawConfigParser()
             f = self._open()
@@ -171,8 +163,7 @@ class BasicKeyring(KeyringBackend):
         return self._config
 
     def get_password(self, service, username):
-        """Read the password from the file.
-        """
+        """Read the password from the file."""
         service = escape_for_ini(service)
         username = escape_for_ini(username)
 
@@ -180,7 +171,7 @@ class BasicKeyring(KeyringBackend):
         try:
             password_base64 = self.config.get(service, username).encode()
             # decode with base64
-            password_encrypted = base64.decodestring(password_base64)
+            password_encrypted = base64.decodebytes(password_base64)
             # decrypted the password
             password = self.decrypt(password_encrypted).decode('utf-8')
         except (configparser.NoOptionError, configparser.NoSectionError):
@@ -188,8 +179,7 @@ class BasicKeyring(KeyringBackend):
         return password
 
     def set_password(self, service, username, password):
-        """Write the password in the file.
-        """
+        """Write the password in the file."""
         service = escape_for_ini(service)
         username = escape_for_ini(username)
 
@@ -198,12 +188,12 @@ class BasicKeyring(KeyringBackend):
         password_encrypted = self.encrypt(password.encode('utf-8'))
 
         # encode with base64
-        password_base64 = base64.encodestring(password_encrypted).decode()
+        password_base64 = base64.encodebytes(password_encrypted).decode()
         # write the modification
         if not self.config.has_section(service):
             self.config.add_section(service)
         self.config.set(service, username, password_base64)
-        config_file = UnicodeWriterAdapter(self._open('w'))
+        config_file = self._open('w')
         self.config.write(config_file)
         config_file.close()
 
@@ -215,7 +205,7 @@ class BasicKeyring(KeyringBackend):
             self.config.remove_option(service, username)
         except configparser.NoSectionError:
             raise errors.PasswordDeleteError('Password not found')
-        config_file = UnicodeWriterAdapter(self._open('w'))
+        config_file = self._open('w')
         self.config.write(config_file)
         config_file.close()
 
@@ -227,48 +217,31 @@ class BasicKeyring(KeyringBackend):
         return 2
 
 
-class UnicodeWriterAdapter(object):
-    """
-    Wrap an object with a .write method to accept 'str' on Python 2
-    and make it a Unicode string.
-    """
-    def __init__(self, orig):
-        self._orig = orig
-
-    def __getattr__(self, *args, **kwargs):
-        return getattr(self._orig, *args, **kwargs)
-
-    def write(self, value):
-        if isinstance(value, str):
-            value = value.decode('ascii')
-        return self._orig.write(value)
-
-
-if sys.version_info > (3,):
-    def UnicodeWriterAdapter(x):  # noqa
-        return x
-
-
 class PlaintextKeyring(BasicKeyring):
-    """Unencrypted Pyfilesystem Keyring
-    """
+    """Unencrypted Pyfilesystem Keyring"""
 
     def __init__(self, filename=None, can_create=True, cache_timeout=None):
         super(PlaintextKeyring, self).__init__(
-            NullCrypter(), filename=filename, can_create=can_create,
-            cache_timeout=cache_timeout)
+            NullCrypter(),
+            filename=filename,
+            can_create=can_create,
+            cache_timeout=cache_timeout,
+        )
+
 
 class EncryptedKeyring(BasicKeyring):
-    """Encrypted Pyfilesystem Keyring
-    """
+    """Encrypted Pyfilesystem Keyring"""
 
     _filename = 'crypted_pyf_pass.cfg'
 
-    def __init__(self, crypter, filename=None, can_create=True,
-                 cache_timeout=None):
+    def __init__(self, crypter, filename=None, can_create=True, cache_timeout=None):
         super(EncryptedKeyring, self).__init__(
-            crypter, filename=filename, can_create=can_create,
-            cache_timeout=cache_timeout)
+            crypter,
+            filename=filename,
+            can_create=can_create,
+            cache_timeout=cache_timeout,
+        )
+
 
 class KeyczarKeyring(EncryptedKeyring):
     """Encrypted Pyfilesystem Keyring using Keyczar keysets specified in
@@ -276,5 +249,4 @@ class KeyczarKeyring(EncryptedKeyring):
     """
 
     def __init__(self):
-        super(KeyczarKeyring, self).__init__(
-            keyczar.EnvironCrypter())
+        super(KeyczarKeyring, self).__init__(keyczar.EnvironCrypter())
